"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const validator_1 = __importDefault(require("./validator"));
const top_level_domains_1 = __importDefault(require("../lib/top-level-domains"));
/**
 * RingCentral requires valid email addresses for nearly all extension types. Here, we enforce good email form and top level domains.
 */
class EmailValidator extends validator_1.default {
    constructor() {
        super();
        this.tldExactMatchRegex = this.setTldExactMatchRegex();
        this.wellFormedRegex = new RegExp(/\w+\@\w+\.\w+/, 'i');
    }
    ;
    toolTip() {
        return "TODO: Email Tooltip";
    }
    ;
    validate(element) {
        let errors = [];
        if (!this.tldExactMatchRegex.test(element)) {
            errors.push("Emails require a valid top level domain");
        }
        ;
        if (!this.wellFormedRegex.test(element)) {
            errors.push("Email format not valid. Should be {something}@{something}.{top level domain}");
        }
        ;
        return new Promise((resolve, reject) => {
            if (errors.length > 0) {
                reject({
                    originalElement: element,
                    errors: errors
                });
            }
            else {
                resolve(true);
            }
            ;
        });
    }
    ;
    /**
     * Generates the huge regex for top level domains
     */
    setTldExactMatchRegex() {
        return new RegExp("\\b((\\" + top_level_domains_1.default.join(")$|(\\") + ")$)\\b", "i");
    }
    ;
}
;
exports.default = EmailValidator;
