"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const validator_1 = __importDefault(require("./validator"));
const pin_1 = __importDefault(require("./pin"));
const password_1 = __importDefault(require("./password"));
const limited_extension_contact_1 = __importDefault(require("./limited-extension-contact"));
const leContactValidator = new limited_extension_contact_1.default();
const pinValidator = new pin_1.default();
const passwordValidator = new password_1.default();
/**
 * Validator for Limited Extensions
 */
class LimitedExtensionValidator extends validator_1.default {
    constructor() {
        super();
    }
    ;
    toolTip() {
        return "Limited Extension";
    }
    ;
    async validate(element, method) {
        let errors = [];
        if (typeof (element) !== 'object') {
            errors.push(`Request is not an object, you sent ${typeof (element)}`);
        }
        ;
        if (element && !element.contact) {
            errors.push(`Limited Extensions requests require a contact object`);
        }
        ;
        if (element && element.contact) {
            let contactResponse = await leContactValidator
                .validate(element.contact)
                .then(res => {
                return res;
            })
                .catch(e => {
                return e;
            });
            if (contactResponse !== true) {
                errors.push({
                    contact: contactResponse
                });
            }
            ;
        }
        ;
        if (element && !element.ivrPin) {
            errors.push(`Limited Extension requests require a PIN`);
        }
        ;
        if (element && element.ivrPin) {
            let pinResponse = await pinValidator
                .validate(element.ivrPin)
                .then(res => {
                return res;
            })
                .catch(e => {
                return e;
            });
            if (pinResponse !== true) {
                errors.push({
                    ivrPin: pinResponse
                });
            }
            ;
        }
        ;
        if (element && !element.password) {
            errors.push(`Limited Extension requests require a password`);
        }
        ;
        if (element && element.password) {
            let passwordResponse = await passwordValidator
                .validate(element.password)
                .then(res => {
                return res;
            })
                .catch(e => {
                return e;
            });
            if (passwordResponse !== true) {
                errors.push({
                    password: passwordResponse
                });
            }
            ;
        }
        ;
        return new Promise((resolve, reject) => {
            if (errors.length > 0) {
                reject({
                    originalElement: element,
                    errors: errors
                });
            }
            else {
                resolve(true);
            }
            ;
        });
    }
    ;
}
;
exports.default = LimitedExtensionValidator;
