"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const validator_1 = __importDefault(require("./validator"));
const numbers_1 = __importDefault(require("../lib/numbers"));
/**
 * RingCentral IVRPin. This is generally used for checking voicemail from a physical device endpoint.
 *
 * https://support.ringcentral.com/article/5766.html
 */
class PinValidator extends validator_1.default {
    constructor() {
        super();
        this.sequentialNumbersRegex = this.createSequentialNumbersRegex();
        this.repeatingNumbersRegex = this.createRepeatedNumbersRegex();
        this.numbersOnlyRegex = new RegExp(/\D/, '');
    }
    ;
    toolTip() {
        return "PINs should be 6-10 characters long, not have 3 repeated numbers, or 3 sequential numbers";
    }
    ;
    validate(element) {
        let errors = [];
        if (this.sequentialNumbersRegex.test(element)) {
            errors.push('PIN cannot contain 3 sequential numbers, like 123');
        }
        ;
        if (this.repeatingNumbersRegex.test(element)) {
            errors.push('PIN cannot contain 3 repeating numbers, like 111');
        }
        ;
        if (this.numbersOnlyRegex.test(element)) {
            errors.push('PINs can only contain numbers');
        }
        ;
        if (element.length < 6 || element.length > 10) {
            errors.push('PIN length must be between 6 and 10 digits');
        }
        ;
        return new Promise((resolve, reject) => {
            if (errors.length > 0) {
                reject({
                    originalElement: element,
                    errors: errors
                });
            }
            else {
                resolve(true);
            }
            ;
        });
    }
    ;
    createRepeatedNumbersRegex() {
        let repeatedNumArr = [];
        for (let i = 0; i < numbers_1.default.length; i++) {
            repeatedNumArr.push(numbers_1.default[i] + numbers_1.default[i] + numbers_1.default[i]);
        }
        ;
        return new RegExp("(" + repeatedNumArr.join('|') + ")", "i");
    }
    ;
    createSequentialNumbersRegex() {
        let sequentialNumbersArray = [];
        for (let i = 0; i < numbers_1.default.length; i++) {
            if (i == 0 || i == numbers_1.default.length - 1) {
                continue;
            }
            ;
            sequentialNumbersArray.push(numbers_1.default[i - 1] + numbers_1.default[i] + numbers_1.default[i + 1]);
        }
        ;
        numbers_1.default.reverse();
        for (let i = 0; i < numbers_1.default.length; i++) {
            if (i == 0 || i == numbers_1.default.length - 1) {
                continue;
            }
            ;
            sequentialNumbersArray.push(numbers_1.default[i - 1] + numbers_1.default[i] + numbers_1.default[i + 1]);
        }
        ;
        return new RegExp("(" + sequentialNumbersArray.join('|') + ")", "i");
    }
    ;
}
;
exports.default = PinValidator;
